Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(674)

Unified Diff: chrome/browser/ui/views/location_bar/icon_label_bubble_view.h

Issue 1419673017: [MD] Twiddle padding of omnibox chips (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: move constant to inline Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/location_bar/icon_label_bubble_view.h
diff --git a/chrome/browser/ui/views/location_bar/icon_label_bubble_view.h b/chrome/browser/ui/views/location_bar/icon_label_bubble_view.h
index 3f746098b78e0f84f5307d12574d61fe31ca2d92..7978cf90dfc113efb3bacc9d4176e77f161a3b13 100644
--- a/chrome/browser/ui/views/location_bar/icon_label_bubble_view.h
+++ b/chrome/browser/ui/views/location_bar/icon_label_bubble_view.h
@@ -78,10 +78,13 @@ class IconLabelBubbleView : public views::View {
gfx::Size GetSizeForLabelWidth(int width) const;
private:
// Amount of padding at the edges of the bubble. If |start| is true, this
// is the padding at the beginning of the bubble (left in LTR), otherwise it's
// the end padding.
- int GetBubbleOuterPadding(bool start) const;
+ int GetBubbleOuterPadding(bool leading) const;
+
+ // As above, but for Material Design. TODO(estade): remove/replace the above.
+ int GetBubbleOuterPaddingMd(bool leading) const;
// Sets a background color on |label_| based on |background_image_color| and
// |parent_background_color_|.
« no previous file with comments | « chrome/browser/ui/views/layout_constants.cc ('k') | chrome/browser/ui/views/location_bar/icon_label_bubble_view.cc » ('j') | no next file with comments »
@@ -78,10 +78,13 @@ class IconLabelBubbleView : public views::View {
gfx::Size GetSizeForLabelWidth(int width) const;
private:
- // Amount of padding at the edges of the bubble. If |start| is true, this
+ // Amount of padding at the edges of the bubble. If |leading| is true, this
// is the padding at the beginning of the bubble (left in LTR), otherwise it's
// the end padding.

Powered by Google App Engine
This is Rietveld 408576698